package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.SiteDeliveryMapper;
import com.ruoyi.system.domain.SiteDelivery;
import com.ruoyi.system.service.ISiteDeliveryService;

/**
 * 快递公司Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@Service
public class SiteDeliveryServiceImpl implements ISiteDeliveryService 
{
    @Autowired
    private SiteDeliveryMapper siteDeliveryMapper;

    /**
     * 查询快递公司
     * 
     * @param id 快递公司主键
     * @return 快递公司
     */
    @Override
    public SiteDelivery selectSiteDeliveryById(Long id)
    {
        return siteDeliveryMapper.selectSiteDeliveryById(id);
    }

    /**
     * 查询快递公司列表
     * 
     * @param siteDelivery 快递公司
     * @return 快递公司
     */
    @Override
    public List<SiteDelivery> selectSiteDeliveryList(SiteDelivery siteDelivery)
    {
        return siteDeliveryMapper.selectSiteDeliveryList(siteDelivery);
    }

    /**
     * 新增快递公司
     * 
     * @param siteDelivery 快递公司
     * @return 结果
     */
    @Override
    public int insertSiteDelivery(SiteDelivery siteDelivery)
    {
        return siteDeliveryMapper.insertSiteDelivery(siteDelivery);
    }

    /**
     * 修改快递公司
     * 
     * @param siteDelivery 快递公司
     * @return 结果
     */
    @Override
    public int updateSiteDelivery(SiteDelivery siteDelivery)
    {
        return siteDeliveryMapper.updateSiteDelivery(siteDelivery);
    }

    /**
     * 批量删除快递公司
     * 
     * @param ids 需要删除的快递公司主键
     * @return 结果
     */
    @Override
    public int deleteSiteDeliveryByIds(Long[] ids)
    {
        return siteDeliveryMapper.deleteSiteDeliveryByIds(ids);
    }

    /**
     * 删除快递公司信息
     * 
     * @param id 快递公司主键
     * @return 结果
     */
    @Override
    public int deleteSiteDeliveryById(Long id)
    {
        return siteDeliveryMapper.deleteSiteDeliveryById(id);
    }
}
